@@ -44,9 +44,7 @@ L.Toolbar.include({
 L.Storage.SettingsToolbar = L.Toolbar.extend({
 
     addToolbar: function (map) {
-        var container = L.DomUtil.create('div', 'leaflet-draw-section'),
-        buttonIndex = 0,
-        buttonClassPrefix = 'leaflet-draw-draw';
+        var container = L.DomUtil.create('div', 'leaflet-draw-section');
         this._toolbarContainer = L.DomUtil.create('div', 'leaflet-draw-toolbar leaflet-bar');
         var actions = map.getEditActions(), action;
         for (var i = 0; i < actions.length; i++) {
@@ -410,7 +408,8 @@ L.Storage.Map.include({
             title = L.DomUtil.add('h3', 'storage-browse-title', browserContainer, this.options.name),
             filter = L.DomUtil.create('input', '', browserContainer),
             filterValue = '',
-            featuresContainer = L.DomUtil.create('div', 'storage-browse-features', browserContainer);
+            featuresContainer = L.DomUtil.create('div', 'storage-browse-features', browserContainer),
+            filterKeys = (this.options.filterKey || this.options.sortKey || 'name').split(',');
         filter.type = 'text';
         filter.placeholder = L._('Filter…');
 
@@ -442,14 +441,14 @@ L.Storage.Map.include({
                 headline = L.DomUtil.create('h5', '', container);
             container.id = 'browse_data_datalayer_' + datalayer.storage_id;
             datalayer.renderToolbox(headline);
-            var title = L.DomUtil.add('span', '', headline, datalayer.options.name),
-                ul = L.DomUtil.create('ul', '', container);
+            L.DomUtil.add('span', '', headline, datalayer.options.name);
+            var ul = L.DomUtil.create('ul', '', container);
             L.DomUtil.classIf(container, 'off', !datalayer.isVisible());
 
             var build = function () {
                 ul.innerHTML = '';
                 datalayer.eachFeature(function (feature) {
-                    if (filterValue && (feature.getDisplayName() || '').toLowerCase().indexOf(filterValue) === -1) return;
+                    if (filterValue && !feature.matchFilter(filterValue, filterKeys)) return;
                     ul.appendChild(addFeature(feature));
                 });
             };
@@ -752,7 +751,8 @@ L.S.IframeExporter = L.Class.extend({
 
     options: {
         includeFullScreenLink: true,
-        currentView: false
+        currentView: false,
+        keepCurrentDatalayers: false
     },
 
     queryString : {
@@ -783,6 +783,17 @@ L.S.IframeExporter = L.Class.extend({
     },
 
     build: function () {
+        var datalayers = [];
+        if (this.options.keepCurrentDatalayers) {
+            this.map.eachDataLayer(function (datalayer) {
+                if (datalayer.isVisible() && datalayer.storage_id) {
+                    datalayers.push(datalayer.storage_id);
+                }
+            });
+            this.queryString.datalayers = datalayers.join(',');
+        } else {
+            delete this.queryString.datalayers;
+        }
         var currentView = this.options.currentView ? window.location.hash : '',
             iframeUrl = this.baseUrl + '?' + L.S.Xhr.buildQueryString(this.queryString) + currentView,
             code = '<iframe width="' + this.dimensions.width + '" height="' + this.dimensions.height + '" frameBorder="0" src="' + iframeUrl +'"></iframe>';
