@@ -94,15 +94,7 @@ L.Storage.FeatureMixin = {
         );
         form = builder.build();
         container.appendChild(form);
-        var options_fields = this.getAdvancedOptions();
-        builder = new L.S.FormBuilder(this, options_fields, {
-            id: 'storage-feature-advanced-properties',
-            callback: this._redraw,
-            callbackContext: this
-        });
-        var advancedProperties = L.DomUtil.createFieldset(container, L._('Advanced properties'));
-        form = builder.build();
-        advancedProperties.appendChild(form);
+        this.appendEditFieldsets(container);
         var advancedActions = L.DomUtil.createFieldset(container, L._('Advanced actions'));
         this.getAdvancedEditActions(advancedActions);
         L.S.fire('ui:start', {data: {html: container}});
@@ -122,6 +114,18 @@ L.Storage.FeatureMixin = {
         }, this);
     },
 
+    appendEditFieldsets: function (container) {
+        var options_fields = this.getAdvancedOptions();
+        builder = new L.S.FormBuilder(this, options_fields, {
+            id: 'storage-feature-advanced-properties',
+            callback: this._redraw,
+            callbackContext: this
+        });
+        var advancedProperties = L.DomUtil.createFieldset(container, L._('Advanced properties'));
+        form = builder.build();
+        advancedProperties.appendChild(form);
+    },
+
     endEdit: function () {},
 
     getDisplayName: function () {
@@ -352,6 +356,14 @@ L.Storage.FeatureMixin = {
             this.bindLabel(L.Util.escapeHTML(this.properties.name), {noHide: true});
             this.showLabel();
         }
+    },
+
+    matchFilter: function (filter, keys) {
+        filter = filter.toLowerCase();
+        for (var i = 0; i < keys.length; i++) {
+            if ((this.properties[keys[i]] || '').toLowerCase().indexOf(filter) !== -1) return true;
+        }
+        return false;
     }
 
 };
@@ -478,6 +490,23 @@ L.Storage.Marker = L.Marker.extend({
         ];
     },
 
+    appendEditFieldsets: function (container) {
+        L.Storage.FeatureMixin.appendEditFieldsets.call(this, container);
+        var coordinatesOptions = [
+            ['_latlng.lat', {handler: 'FloatInput', label: L._('Latitude')}],
+            ['_latlng.lng', {handler: 'FloatInput', label: L._('Longitude')}]
+        ];
+        builder = new L.S.FormBuilder(this, coordinatesOptions, {
+            callback: function () {
+                this._redraw();
+                this.bringToCenter();
+            },
+            callbackContext: this
+        });
+        var fieldset = L.DomUtil.createFieldset(container, L._('Coordinates'));
+        fieldset.appendChild(builder.build());
+    },
+
     bringToCenter: function (e, callback) {
         callback = callback || function (){};  // mandatory for zoomToShowLayer
         if (this.datalayer.isClustered() && !this._icon) {
