@@ -74,6 +74,8 @@ L.Storage.Map.include({
         this.overrideBooleanOptionFromQueryString('datalayersControl');
         this.overrideBooleanOptionFromQueryString('displayDataBrowserOnLoad');
         this.overrideBooleanOptionFromQueryString('displayCaptionOnLoad');
+        this.datalayersOnLoad = L.Util.queryString('datalayers');
+        if (this.datalayersOnLoad) this.datalayersOnLoad = this.datalayersOnLoad.toString().split(',');
         if (L.Browser.ielt9) {
             // TODO include ie9
             this.options.allowEdit = false;
@@ -474,7 +476,7 @@ L.Storage.Map.include({
             east = parseFloat(this.options.limitBounds.east);
         if (!isNaN(south) && !isNaN(west) && !isNaN(north) && !isNaN(east)) {
             var bounds = L.latLngBounds([[south, west], [north, east]]);
-            this.options.minZoom = this.getBoundsZoom(bounds, true);
+            this.options.minZoom = this.getBoundsZoom(bounds, false);
             try {
                 this.setMaxBounds(bounds);
             } catch (e) {
@@ -530,6 +532,7 @@ L.Storage.Map.include({
             ['dimensions.height', {handler: 'Input', label: L._('height')}],
             ['options.includeFullScreenLink', {handler: 'CheckBox', helpText: L._('Include full screen link?')}],
             ['options.currentView', {handler: 'CheckBox', helpText: L._('Current view instead of default map view?')}],
+            ['options.keepCurrentDatalayers', {handler: 'CheckBox', helpText: L._('Keep current visible layers')}],
             'queryString.moreControl',
             'queryString.datalayersControl',
             'queryString.zoomControl',
@@ -877,6 +880,7 @@ L.Storage.Map.include({
             'captionBar',
             'slideshow',
             'sortKey',
+            'filterKey',
             'showLabel',
             'shortCredit',
             'longCredit'
@@ -1024,13 +1028,15 @@ L.Storage.Map.include({
             'options.popupContentTemplate',
             'options.zoomTo',
             'options.showLabel',
-            ['options.sortKey', {handler: 'Input', helpText: L._('Property to use for sorting features'), placeholder: L._('Default: name')}]
+            ['options.sortKey', {handler: 'BlurInput', helpText: L._('Property to use for sorting features'), placeholder: L._('Default: name')}],
+            ['options.filterKey', {handler: 'Input', helpText: L._('Comma separated list of properties to use when filtering features'), placeholder: L._('Default: name')}]
         ];
 
         builder = new L.S.FormBuilder(this, optionsFields, {
             callback: function (field) {
                 if (field !== 'options.popupTemplate' && field !== 'options.popupContentTemplate') {
                     this.eachDataLayer(function (datalayer) {
+                        if (field === 'options.sortKey') datalayer.reindex();
                         datalayer.redraw();
                     });
                 }
@@ -1072,7 +1078,8 @@ L.Storage.Map.include({
             callbackContext: this
         });
         limitBounds.appendChild(boundsBuilder.build());
-        var setCurrentButton = L.DomUtil.add('a', '', limitBounds, L._('Use current bounds'));
+        var boundsButtons = L.DomUtil.create('div', 'button-bar', limitBounds);
+        var setCurrentButton = L.DomUtil.add('a', 'button half', boundsButtons, L._('Use current bounds'));
         setCurrentButton.href = '#';
         L.DomEvent.on(setCurrentButton, 'click', function () {
             var bounds = this.getBounds();
@@ -1084,6 +1091,17 @@ L.Storage.Map.include({
             this.isDirty = true;
             this.handleLimitBounds();
         }, this);
+        var emptyBounds = L.DomUtil.add('a', 'button half', boundsButtons, L._('Empty'));
+        emptyBounds.href = '#';
+        L.DomEvent.on(emptyBounds, 'click', function () {
+            this.options.limitBounds.south = null;
+            this.options.limitBounds.west = null;
+            this.options.limitBounds.north = null;
+            this.options.limitBounds.east = null;
+            boundsBuilder.fetchAll();
+            this.isDirty = true;
+            this.handleLimitBounds();
+        }, this);
 
         var slideshow = L.DomUtil.createFieldset(container, L._('Slideshow'));
         var slideshowFields = [
