@@ -5,13 +5,6 @@ L.S.Layer = {
         return this._layers;
     },
 
-    eachFeature: function (method, context) {
-        var features = this.getFeatures();
-        for (var i in features) {
-            method.call(context || this, features[i]);
-        }
-    },
-
     getEditableOptions: function () {return [];},
 
     postUpdate: function () {}
@@ -29,6 +22,7 @@ L.S.Layer.Default = L.FeatureGroup.extend({
 
 });
 
+
 L.S.Layer.Cluster = L.MarkerClusterGroup.extend({
     _type: 'Cluster',
     includes: [L.S.Layer],
@@ -69,10 +63,6 @@ L.S.Layer.Cluster = L.MarkerClusterGroup.extend({
         if (field === 'options.color') {
             this.options.polygonOptions.color = this.datalayer.getColor();
         }
-    },
-
-    eachFeature: function (method, context) {
-        this.eachLayer(method, context);
     }
 
 });
@@ -193,7 +183,8 @@ L.Storage.DataLayer = L.Class.extend({
         this.setStorageId(data.id);
         this.setOptions(data);
         this.connectToMap();
-        if(this.options.displayOnLoad) {
+        if ((this.map.datalayersOnLoad && this.storage_id && this.map.datalayersOnLoad.indexOf(this.storage_id.toString()) !== -1) ||
+            (!this.map.datalayersOnLoad && this.options.displayOnLoad)) {
             this.show();
         }
         if (!this.storage_id) {
@@ -242,8 +233,10 @@ L.Storage.DataLayer = L.Class.extend({
     },
 
     eachFeature: function (method, context) {
-        if (this.layer) {
-            this.layer.eachFeature(method, context || this);
+        if (this.layer && this.layer.isBrowsable) {
+            for (var i = 0; i < this._index.length; i++) {
+                method.call(context || this, this._layers[this._index[i]]);
+            }
         }
         return this;
     },
@@ -287,6 +280,18 @@ L.Storage.DataLayer = L.Class.extend({
         }
     },
 
+    reindex: function () {
+        var features = [];
+        this.eachFeature(function (feature) {
+            features.push(feature);
+        });
+        L.Util.sortFeatures(features, this.map.getOption('sortKey'));
+        this._index = [];
+        for (var i = 0; i < features.length; i++) {
+            this._index.push(L.Util.stamp(features[i]));
+        }
+    },
+
     fetchRemoteData: function () {
         var from = parseInt(this.options.remoteData.from, 10),
             to = parseInt(this.options.remoteData.to, 10);
@@ -461,21 +466,10 @@ L.Storage.DataLayer = L.Class.extend({
 
     geojsonToFeatures: function (geojson) {
         var features = geojson instanceof Array ? geojson : geojson.features,
-            i, len, sortKey = this.map.options.sortKey || 'name';
+            i, len;
 
         if (features) {
-            features.sort(function (a, b) {
-                if (!a.properties || !b.properties) {
-                    return 0;
-                } else if (!a.properties[sortKey] && !b.properties[sortKey]) {
-                    return 0;
-                } else if (!a.properties[sortKey]) {
-                    return -1;
-                } else if (!b.properties[sortKey]) {
-                    return 1;
-                }
-                return a.properties.name.toString().localeCompare(b.properties.name.toString());
-            });
+            L.Util.sortFeatures(features, this.map.getOption('sortKey'));
             for (i = 0, len = features.length; i < len; i++) {
                 this.geojsonToFeatures(features[i]);
             }
@@ -834,7 +828,7 @@ L.Storage.DataLayer = L.Class.extend({
     getNextVisible: function () {
         var id = this.map.datalayers_index.indexOf(this),
             next = this.map.datalayers_index[id + 1] || this.map.datalayers_index[0];
-        while(!next.isVisible() || next._index.length === 0 || !next.isBrowsable()) {
+        while(!next.isVisible() || !next.isBrowsable() || next._index.length === 0) {
             next = next.getNextVisible();
         }
         return next;
@@ -843,7 +837,7 @@ L.Storage.DataLayer = L.Class.extend({
     getPreviousVisible: function () {
         var id = this.map.datalayers_index.indexOf(this),
             prev = this.map.datalayers_index[id - 1] || this.map.datalayers_index[this.map.datalayers_index.length - 1];
-        while(!prev.isVisible() || prev._index.length === 0 || !prev.isBrowsable()) {
+        while(!prev.isVisible() || !prev.isBrowsable() || prev._index.length === 0) {
             prev = prev.getPreviousVisible();
         }
         return prev;
